#ifndef XBMC_H
#define XBMC_H

#include "xbmcclient.h"

#include <QString>

class Xbmc
{
public:
    Xbmc();
    ~Xbmc();

    void setup();

    void actionRight();
    void actionLeft();
    void actionUp();
    void actionDown();

    void actionMute();
    void actionVolumeUp();
    void actionVolumeDown();

    void actionNextSubtitle();
    void actionNextLanguage();

    void actionPlay();
    void actionStop();

    void actionSelect();

    void actionShowGui();
    void actionSendKeyEsc();
    void actionContextMenu();

private:
    int m_socket;
    CAddress *m_address;
};

#endif // XBMC_H
